\name{spacegraph}
\alias{spacegraph}
\title{Automated search through the space of possible matching solutions}
\description{
Automated search through the space of possible matching solutions
}
\usage{
spacegraph(treatment, data, drop=NULL, mvars=NULL, rgrouping=F, groups=NULL, psmpoly=1, mdmpoly=1, cem.R=10, psm.R=10, mdm.R=10, rawprof=NULL, rawprof.M = 100, maximal=10, ...)
}
\arguments{
  \item{treatment}{character, name of the treatment variable}
  \item{data}{a data.frame}
  \item{drop}{a vector of variable names in the data frame to ignore 
    during matching.  Cannot be specified with \code{mvars}.}
  \item{mvars}{a vector of variable names in the data frame to include 
    in matching.  Cannot be specified with \code{drop}.}  
  \item{rgrouping}{Boolean, specifies whether levels of categorical variables should be randomly grouped together by CEM.}
  \item{groups}{named list, each element of which is a list of
    allowable groupings for a single categorical variable.}
  \item{psmpoly}{numeric, specifying the order of polynomials to include in the propensity score models.  At the moment, only \code{psmpoly=1} is available and other values will throw warnings.}
  \item{psmpoly}{numeric, specifying the order of polynomials to include in Mahalanobis matching.  At the moment, only \code{mdmpoly=1} is available and other values will throw warnings.}
  \item{cem.R}{numeric, the number of random CEM solutions to generate.}
  \item{psm.R}{numeric, the number of random propensity score matching solutions to generate.}
  \item{mdm.R}{numeric, the number of random Mahalanobis distance matching solutions to generate.}
  \item{rawprof}{an optional \code{L1.profile} object to be used for the calculation of the L1 measure.  Specifying this option saves computation time if running \code{spacegraph} multiple times with the same L1.}
  \item{rawprof.M}{numeric, specifies the number of L1 binnings that used to find the median L1 used to compare matching solutions.}
  \item{maximal}{numeric, the maximum number of random cut-points used by CEM.}
}

\details{
This is a tool to help the user to the search for optimal matching solutions by generating many matching solutions from a variety of matching algorithms (currently CEM, Mahalanobis distance matching, and propensity score matching are supported).  The resulting object can be plotted with \code{\link{plot.spg}} to show where each solution falls along the bais-variance tradeoff.

} 
\value{
  Returns a named list of matching solutions that can be used directly with \code{\link{plot.spg}} to produce a spacegraph.
  \item{cem}{a named list containing two objects: \code{cem$space} and \code{cem$cem.objs}.  \code{space} is a tabular summary of the randomly generated CEM solutions, ranked by L1.  The rownames of \code{cem$space} indicate the number of each CEM solution, which is used to retrieve that solution from the list of \code{cem.objs}.  \code{cem.objs} is a list of CEM objects, where the number in the list corresponds to the rownames of \code{cem$space}.  For more about CEM objects see \code{\link{cem}}.
  \item{psm}{a named list containing two named objects: \code{psm$tab} and \code{psm$matched}.  \code{tab} is a tabular summary of the randomly generated propensity score matching solutions.  Currently, these are not ranked.  The rownames of \code{psm$tab} indicate the number of each PSM solution, which is used to retrieve that solution from the list of \code{psm$matched}.  \code{matched} is a list, each element of which is a vector of row names from the original dataset to be included in the matched sample.  To create the PSM matched sample, simply grab these rows (and only these rows) from the original data (returned as \code{data}).}
  \item{mdm}{a named list containing two named objects: \code{mdm$tab} and \code{mdm$matched}.  \code{tab} is a tabular summary of the randomly generated Mahalanobis distance matching solutions.  Currently, these are not ranked.  The rownames of \code{mdm$tab} indicate the number of each MDM solution, which is used to retrieve that solution from the list of \code{mdm$matched}.  \code{matched} is a list, each element of which is a vector of row names from the original dataset to be included in the matched sample.  To create the MDM matched sample, simply grab these rows (and only these rows) from the original data (returned as \code{data}).}
  \item{rawprof}{the \code{L1.profile} object containing the median L1 used to compare matching solutions.}
  \item{data}{the dataset, with row names preserved so that matched samples can be extracted using observation IDs.}
}
\references{}
\author{Richard Nielsen}
\seealso{ \code{\link{cemspace}} }
\examples{
data(LL)
myvars <- names(LL)[c(2:8,10:12)]
out <- spacegraph(treatment="treated",
                  rgrouping=F,
                  data = LL,
                  mvars = myvars,
                  cem.R=10,psm.R=10,mdm.R=10,rawprof.M=100,
                  mdmpoly=1,psmpoly=2,
                  maximal=30)

plot.spg(out, main="Example Space Graph\nLalonde Data")

  ## The numbers in the plot indicate the row of the matching solution
  ## EXAMPLE: accessing CEM solution 2
out$cem$space
out$cem$cem.objs[[2]]
  ## EXAMPLE: accessing PSM solution 5
out$psm$tab[5,]
out$psm$matched[[5]]
  ## EXAMPLE: accessing MDM solution 3
out$mdm$tab[3,]
out$mdm$matched[[3]]

}
\keyword{datagen}

